#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `l10n_si` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-l10n-si",
    version = "7.0.355",
    description = "Slovenian - Accounting",
    long_description = 
"""
Kontni načrt za gospodarske družbe
""",
    url = "http://www.mentis.si",
    author = "Mentis d.o.o.",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.l10n_si': ".",
    },
    packages = ["openerp.addons.l10n_si"],
    package_data = {
        'openerp.addons.l10n_si': ["i18n/*.po*","l10n_si_wizard.xml","data/account.fiscal.position.account.template.csv","data/account.fiscal.position.tax.template.csv","data/account.tax.template.csv","data/account.account.type.csv","data/account.chart.template.csv","data/account.tax.code.template.csv","data/account.account.template.csv","data/account.fiscal.position.template.csv","static/src/img/icon.png","data/account.account.type.csv","data/account.account.template.csv","data/account.tax.code.template.csv","data/account.chart.template.csv","data/account.tax.template.csv","data/account.fiscal.position.template.csv","data/account.fiscal.position.account.template.csv","data/account.fiscal.position.tax.template.csv","l10n_si_wizard.xml"],
    },
    install_requires = ["openerp-account","openerp-base-iban","openerp-base-vat","openerp-account-chart","openerp-account-cancel"],
    tests_require = ["unittest2"],
)
